Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
var ( // ProjectID is gcp project id ProjectID = "" // CallerDepth is the number of stack frames to ascend CallerSkip = 0 // WriteAccessLog is function that writes an access log WriteAccessLog types.WriteAccessLogFunc // ApplicationLogOut is io.Writer object for application log ApplicationLogOut io.Writer // AccessLogOut is io.Writer object for access log AccessLogOut io.Writer )
Functions ¶
func SetContextConfig ¶
func SetContextConfig(ctx context.Context, cs *ContextConfig) context.Context
GetContextConfig sets the ContextConfig instance to context
Types ¶
type ContextConfig ¶
type ContextConfig struct {
// ApplicationLogOut is io.Writer object for application log
ApplicationLogOut io.Writer
// AccessLogOut is io.Writer object for access log
AccessLogOut io.Writer
}
func GetContextConfig ¶
func GetContextConfig(ctx context.Context) *ContextConfig
GetContextConfig gets the ContextSeverity instance from context
Click to show internal directories.
Click to hide internal directories.